==> owncloud-9.0.2-2-any.pkg.tar.xz: usr/share/webapps/owncloud/apps/activity/l10n/es_AR.js <==
OC.L10N.register(
    "activity",
    {
    "Activity" : "Actividad",
    "Personal activity feed for %s" : "Secuencia de actividad Personal para %s",
    "Your feed URL is invalid" : "Su alimentador URL es inválido",
    "Your settings have been updated." : "Tu configuración ha sido actualizada",
    "Mail" : "Dirección de correo electrónico",
    "Stream" : "Compartir",
    "Activities" : "Actividades",
    "Error loading activities" : "Error al cargar actividades",
    "No activities" : "No hay actividades",
    ", " : ", ",
    "This stream will show events like additions, changes & shares" : "Este fujo mostrará eventos agregados, modificados y compartidos.",
    "There are no events for this filter" : "No hay eventos para este filtro",
    "Today" : "Hoy",
    "Yesterday" : "Ayer",
    "\"remote user\"" : "\"usuario remoto\"",
    "Activity notification" : "Notificación de Actividad",
    "All Activities" : "Todas las Actividades",
    "Activities by you" : "Tus Actividades",
    "Activities by others" : "Actividades de tus amigos",
    "%s and %s" : "%s y %s",
    "Hello %s," : "Hola %s:",
    "You are receiving this email because the following things happened at %s" : "Está recibiendo este mensaje porque durante el último día han pasado las siguientes cosas en %s",
    "* %1$s - %2$s" : "* %1$s - %2$s",
    "_* and %n more _::_* and %n more _" : ["* y %n más","* y %n más"],
    "List your own actions in the stream" : "Listar sus propias acciones en el flujo de notificaciones",
    "Notify about your own actions via email" : "Notificar de tus acciones vía email",
    "You need to set up your email address before you can receive notification emails." : "Necesitas configurar tu dirección de correo electrónico antes de poder recibir las notificaciones en tu correo electrónico.",
    "Send emails:" : "Enviar correo electrónico:",
    "Hourly" : "Horas",
    "Daily" : "Diariamente",
    "Weekly" : "Semanalmente",
    "Activity feed" : "Secuencia de Actividad",
    "Enable RSS feed" : "Permitido RSS feed",
    "No activity yet" : "Ninguna actividad aún",
    "No more events to load" : "No hay más eventos para cargar",
    "Files" : "Archivos"
},
"nplurals=2; plural=(n != 1);");

==> owncloud-9.1.1-1-any.pkg.tar.xz: usr/share/webapps/owncloud/apps/activity/l10n/es_AR.js <==
OC.L10N.register(
    "activity",
    {
    "Activity" : "Actividad",
    "Activities" : "Actividades",
    "Error loading activities" : "Error al cargar actividades",
    "No activities" : "No hay actividades",
    "Load more activities" : "Cargar mas actividades",
    ", " : ", ",
    "{parameterList} and {lastParameter}" : "{parameterList} y {lastParameter}",
    "in {directory}" : "en el {directory}",
    "This stream will show events like additions, changes & shares" : "Este fujo mostrará eventos agregados, modificados y compartidos.",
    "There are no events for this filter" : "No hay eventos para este filtro",
    "Today" : "Hoy",
    "Yesterday" : "Ayer",
    "Personal activity feed for %s" : "Secuencia de actividad Personal para %s",
    "Your feed URL is invalid" : "Su alimentador URL es inválido",
    "Your settings have been updated." : "Tu configuración ha sido actualizada",
    "Mail" : "Dirección de correo electrónico",
    "Stream" : "Compartir",
    "\"remote user\"" : "\"usuario remoto\"",
    "Activity notification" : "Notificación de Actividad",
    "All Activities" : "Todas las Actividades",
    "Activities by you" : "Tus Actividades",
    "Activities by others" : "Actividades de tus amigos",
    "%s and %s" : "%s y %s",
    "Hello %s," : "Hola %s:",
    "You are receiving this email because the following things happened at %s" : "Está recibiendo este mensaje porque durante el último día han pasado las siguientes cosas en %s",
    "* %1$s - %2$s" : "* %1$s - %2$s",
    "_* and %n more _::_* and %n more _" : ["* y %n más","* y %n más"],
    "List your own file actions in the stream" : "Listar sus propias acciones en el flujo de notificaciones",
    "Notify about your own actions via email" : "Notificar de tus acciones vía email",
    "You need to set up your email address before you can receive notification emails." : "Necesitas configurar tu dirección de correo electrónico antes de poder recibir las notificaciones en tu correo electrónico.",
    "Send emails:" : "Enviar correo electrónico:",
    "Hourly" : "Horas",
    "Daily" : "Diariamente",
    "Weekly" : "Semanalmente",
    "Activity feed" : "Secuencia de Actividad",
    "Enable RSS feed" : "Permitido RSS feed",
    "No activity yet" : "Ninguna actividad aún",
    "No more events to load" : "No hay más eventos para cargar",
    "Files" : "Archivos"
},
"nplurals=2; plural=(n != 1);");
